@@ -1,4 +1,4 @@
-from . import Events, Network, Plans, TripEventHandler
+from . import Events, Network, Plans, TripEventHandler, writers
 
 read_network = Network.read_network
 event_reader = Events.event_reader
